@@ -24,5 +24,3 @@
  */
 
 let LOCALE_DIR = '/usr/local/share/locale';
-let ICONS_DIR = '/usr/local/share/sushi/icons/';
-let STYLE_DIR = '/usr/local/share/sushi/style/';
\ No newline at end of file
